Introduction
============

``debops.prosody`` configures and manages the XMPP server prosody.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run::

    ansible-galaxy install debops.prosody

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
